@@ -31,7 +31,7 @@ class S3UtilsTest(unittest.TestCase):
 
     def test_s3_list_object__random_text_files(self):
         with moto.mock_aws(), s3_make_client() as client:
-            client.client.create_bucket(Bucket="dummy-bucket")
+            client.create_bucket(Bucket="dummy-bucket")
 
             data = []
             for i in range(0, 2000):
@@ -49,7 +49,7 @@ class S3UtilsTest(unittest.TestCase):
                 self.assertEqual(s3_pull_text(client, "dummy-bucket", key), text)
 
         with moto.mock_aws(), s3_make_progressed_client() as client:
-            client.client.create_bucket(Bucket="dummy-bucket")
+            client.create_bucket(Bucket="dummy-bucket")
 
             data = []
             for i in range(0, 2000):
@@ -58,17 +58,17 @@ class S3UtilsTest(unittest.TestCase):
                 data.append((key, text))
 
             for key, text in data:
-                client.CloudPath("s3://dummy-bucket/", key).write_text(text)
+                s3_push_text(client, text, "dummy-bucket", key)
 
             result = list(s3_list_objects(client, "dummy-bucket", "dummy_prefix/"))
 
             for key, text in data:
                 self.assertTrue(any(o.key == key for o in result))
-                self.assertEqual(client.CloudPath("s3://dummy-bucket", key).read_text(), text)
+                self.assertEqual(s3_pull_text(client, "dummy-bucket", key), text)
 
     def test_s3_listfile__random_text_files(self):
         with moto.mock_aws(), s3_make_client() as client:
-            client.client.create_bucket(Bucket="dummy-bucket")
+            client.create_bucket(Bucket="dummy-bucket")
 
             data = []
             for i in range(0, 2000):
@@ -86,7 +86,7 @@ class S3UtilsTest(unittest.TestCase):
                 self.assertEqual(s3_pull_text(client, "dummy-bucket", key), text)
 
         with moto.mock_aws(), s3_make_progressed_client() as client:
-            client.client.create_bucket(Bucket="dummy-bucket")
+            client.create_bucket(Bucket="dummy-bucket")
 
             data = []
             for i in range(0, 2000):
@@ -95,13 +95,13 @@ class S3UtilsTest(unittest.TestCase):
                 data.append((key, text))
 
             for key, text in data:
-                client.CloudPath("s3://dummy-bucket/", key).write_text(text)
+                s3_push_text(client, text, "dummy-bucket", key)
 
             result = list(s3_listfile(client, "dummy-bucket", "dummy_prefix/"))
 
             for key, text in data:
                 self.assertTrue(any(o.key == key for o in result))
-                self.assertEqual(client.CloudPath("s3://dummy-bucket", key).read_text(), text)
+                self.assertEqual(s3_pull_text(client, "dummy-bucket", key), text)
 
     data_s3_listfile = [
         (
@@ -236,7 +236,7 @@ class S3UtilsTest(unittest.TestCase):
     @ddt.unpack
     def test_s3_listfile(self, src, bucket, prefix, include_patterns, exclude_patterns, depth, expect):
         with moto.mock_aws(), s3_make_client() as client:
-            client.client.create_bucket(Bucket=bucket)
+            client.create_bucket(Bucket=bucket)
 
             s3_sync_upload(client,
                            os.path.join(resources_directory, src),
@@ -394,7 +394,7 @@ class S3UtilsTest(unittest.TestCase):
     @ddt.unpack
     def test_s3_sync(self, src, dst, bucket, prefix, include_patterns, exclude_patterns, depth, expect):
         with moto.mock_aws(), s3_make_client() as client:
-            client.client.create_bucket(Bucket=bucket)
+            client.create_bucket(Bucket=bucket)
 
             s3_sync_upload(client,
                            os.path.join(resources_directory, src),
@@ -414,7 +414,7 @@ class S3UtilsTest(unittest.TestCase):
                                     set(map(lambda x: norm_path(os.path.join(temp_directory, x)), expect)))
 
         with moto.mock_aws(), s3_make_client() as client:
-            client.client.create_bucket(Bucket=bucket)
+            client.create_bucket(Bucket=bucket)
 
             s3_sync_upload(client,
                            os.path.join(resources_directory, src),
@@ -434,7 +434,7 @@ class S3UtilsTest(unittest.TestCase):
                                     set(map(lambda x: norm_path(os.path.join(temp_directory, x)), expect)))
 
         with moto.mock_aws(), s3_make_client() as client:
-            client.client.create_bucket(Bucket=bucket)
+            client.create_bucket(Bucket=bucket)
 
             s3_sync_upload(client,
                            os.path.join(resources_directory, src),
@@ -467,7 +467,7 @@ class S3UtilsTest(unittest.TestCase):
     @ddt.unpack
     def test_s3_text(self, bucket, key, text, encoding):
         with moto.mock_aws(), s3_make_client() as client:
-            client.client.create_bucket(Bucket=bucket)
+            client.create_bucket(Bucket=bucket)
 
             s3_push_text(client, text, bucket, key, encoding=encoding)
             self.assertEqual(s3_pull_text(client, bucket, key, encoding=encoding), text)
@@ -478,7 +478,7 @@ class S3UtilsTest(unittest.TestCase):
             moto_server_endpoint_url() as endpoint_url,
             s3_make_client(endpoint_url=endpoint_url) as client,
         ):
-            client.client.create_bucket(Bucket="dummy-bucket")
+            client.create_bucket(Bucket="dummy-bucket")
 
             s3_sync_upload(client,
                            os.path.join(resources_directory, "unittest", "s3utils_archive"),
@@ -538,7 +538,7 @@ class S3UtilsTest(unittest.TestCase):
             moto_server_endpoint_url() as endpoint_url,
             s3_make_client(endpoint_url=endpoint_url) as client,
         ):
-            client.client.create_bucket(Bucket="dummy-bucket")
+            client.create_bucket(Bucket="dummy-bucket")
 
             s3_sync_upload(client,
                            os.path.join(resources_directory, "unittest", "s3utils_archive"),
@@ -565,7 +565,7 @@ class S3UtilsTest(unittest.TestCase):
             moto_server_endpoint_url() as endpoint_url,
             s3_make_client(endpoint_url=endpoint_url) as client,
         ):
-            client.client.create_bucket(Bucket="dummy-bucket")
+            client.create_bucket(Bucket="dummy-bucket")
 
             s3_sync_upload(client,
                            os.path.join(resources_directory, "unittest", "s3utils_archive"),
