@@ -13,8 +13,8 @@ from plexus.common.utils.strutils import kebab_case_parser, kebab_case_pattern
 from plexus.common.utils.strutils import parse_bag_name, parse_user_email, parse_user_name, parse_vehicle_name
 from plexus.common.utils.strutils import snake_case_parser, snake_case_pattern
 from plexus.common.utils.strutils import strict_abspath_parser, strict_abspath_pattern
-from plexus.common.utils.strutils import strict_archive_abspath_parser, strict_archive_abspath_pattern
-from plexus.common.utils.strutils import strict_archive_relpath_parser, strict_archive_relpath_pattern
+from plexus.common.utils.strutils import strict_fragmented_abspath_parser, strict_fragmented_abspath_pattern
+from plexus.common.utils.strutils import strict_fragmented_relpath_parser, strict_fragmented_relpath_pattern
 from plexus.common.utils.strutils import strict_relpath_parser, strict_relpath_pattern
 from plexus.common.utils.strutils import topic_parser, topic_pattern
 from plexus.common.utils.strutils import vin_code_parser, vin_code_pattern
@@ -379,7 +379,7 @@ class StrUtilsTest(unittest.TestCase):
         with self.assertRaises(pp.ParseException):
             strict_abspath_parser.parse_string(data, parse_all=True)
 
-    data_strict_archive_relpath_pattern = [
+    data_strict_fragmented_relpath_pattern = [
         ("archive.zip",),
         ("directory/archive.zip",),
         ("directory/dummy/archive.zip",),
@@ -399,13 +399,13 @@ class StrUtilsTest(unittest.TestCase):
         ("directory/dummy/.path_to-archive.zip#directory/dummy/.path_to-file.txt",),
     ]
 
-    @ddt.idata(data_strict_archive_relpath_pattern)
+    @ddt.idata(data_strict_fragmented_relpath_pattern)
     @ddt.unpack
-    def test_strict_archive_relpath_pattern(self, data):
-        self.assertIsNotNone(strict_archive_relpath_pattern.match(data))
-        self.assertIsNotNone(strict_archive_relpath_parser.parse_string(data, parse_all=True))
+    def test_strict_fragmented_relpath_pattern(self, data):
+        self.assertIsNotNone(strict_fragmented_relpath_pattern.match(data))
+        self.assertIsNotNone(strict_fragmented_relpath_parser.parse_string(data, parse_all=True))
 
-    data_strict_archive_relpath_pattern__bad_cases = [
+    data_strict_fragmented_relpath_pattern__bad_cases = [
         ("/archive.zip",),
         ("/directory/archive.zip",),
         ("/directory/dummy/archive.zip",),
@@ -446,14 +446,14 @@ class StrUtilsTest(unittest.TestCase):
         ("directory/archive.zip#directory/\n/dummy",),
     ]
 
-    @ddt.idata(data_strict_archive_relpath_pattern__bad_cases)
+    @ddt.idata(data_strict_fragmented_relpath_pattern__bad_cases)
     @ddt.unpack
-    def test_strict_archive_relpath_pattern__bad_cases(self, data):
-        self.assertIsNone(strict_archive_relpath_pattern.match(data))
+    def test_strict_fragmented_relpath_pattern__bad_cases(self, data):
+        self.assertIsNone(strict_fragmented_relpath_pattern.match(data))
         with self.assertRaises(pp.ParseException):
-            strict_archive_relpath_parser.parse_string(data, parse_all=True)
+            strict_fragmented_relpath_parser.parse_string(data, parse_all=True)
 
-    data_strict_archive_abspath_pattern = [
+    data_strict_fragmented_abspath_pattern = [
         ("/archive.zip",),
         ("/directory/archive.zip",),
         ("/directory/dummy/archive.zip",),
@@ -473,13 +473,13 @@ class StrUtilsTest(unittest.TestCase):
         ("/directory/dummy/.path_to-archive.zip#directory/dummy/.path_to-file.txt",),
     ]
 
-    @ddt.idata(data_strict_archive_abspath_pattern)
+    @ddt.idata(data_strict_fragmented_abspath_pattern)
     @ddt.unpack
-    def test_strict_archive_abspath_pattern(self, data):
-        self.assertIsNotNone(strict_archive_abspath_pattern.match(data))
-        self.assertIsNotNone(strict_archive_abspath_parser.parse_string(data, parse_all=True))
+    def test_strict_fragmented_abspath_pattern(self, data):
+        self.assertIsNotNone(strict_fragmented_abspath_pattern.match(data))
+        self.assertIsNotNone(strict_fragmented_abspath_parser.parse_string(data, parse_all=True))
 
-    data_strict_archive_abspath_pattern__bad_cases = [
+    data_strict_fragmented_abspath_pattern__bad_cases = [
         ("archive.zip",),
         ("directory/archive.zip",),
         ("directory/dummy/archive.zip",),
@@ -520,12 +520,12 @@ class StrUtilsTest(unittest.TestCase):
         ("/directory/archive.zip#directory/\n/dummy",),
     ]
 
-    @ddt.idata(data_strict_archive_abspath_pattern__bad_cases)
+    @ddt.idata(data_strict_fragmented_abspath_pattern__bad_cases)
     @ddt.unpack
-    def test_strict_archive_abspath_pattern__bad_cases(self, data):
-        self.assertIsNone(strict_archive_abspath_pattern.match(data))
+    def test_strict_fragmented_abspath_pattern__bad_cases(self, data):
+        self.assertIsNone(strict_fragmented_abspath_pattern.match(data))
         with self.assertRaises(pp.ParseException):
-            strict_archive_abspath_parser.parse_string(data, parse_all=True)
+            strict_fragmented_abspath_parser.parse_string(data, parse_all=True)
 
     data_email_address_pattern = [
         ("someone@dummy.com",),
